@@ -3,6 +3,7 @@ create table posts (postid integer primary key, pgroupid integer, ppersonid inte
 create table comments (commentid integer primary key, cpostid integer, cpersonid integer, parentid integer, cxid text, capid text, cdt text, subject text, ccontent text, cmeta text);
 create table chats (chatid integer primary key, cgroupid integer, cpersonid integer, cxid text, capid text, cdt text, ccontent text);
 create table persons (personid integer primary key, pname text, display text, papid text, personmeta text);
+create table metagroups (metagroupid integer, groupid integer);
 
 
 create table subs (subid integer primary key, userid integer, groupid integer, personid integer, postid integer);
@@ -18,9 +19,11 @@ create table reports (reportid integer primary key, who text, what text, were te
 create table tombstones (tombstoneid integer primary key, what text);
 create table notifs (notifid integer primary key, userid integer, dt text, flags integer, msg text, url text);
 create table filters (filterid integer primary key, userid integer, data text);
+create table tags (tag text, postid integer, commentid integer);
 
 create index idxgroups_name on groups(gname);
 create index idxgroups_apid on groups(gapid);
+create index idxmetagroups_id on metagroups(metagroupid);
 create index idxposts_groupid on posts(pgroupid);
 create index idxposts_personid on posts(ppersonid);
 create index idxposts_xid on posts(postxid);
@@ -51,6 +54,9 @@ create index idxfollows_what on follows(what);
 create index idxdeliveries_rcpt on deliveries(rcpt);
 create index idxnotifs_userid on notifs(userid);
 create index idxtombstones_what on tombstones(what);
+create index idxtags_tag on tags(tag);
+create index idxtags_postid on tags(postid) where postid > 0;
+create index idxtags_commentid on tags(commentid) where commentid > 0;
 
 create table config (key text, value text);
 
